@@ -1,23 +1,21 @@
 use super::attributes::extract_doc;
 use super::method_parse::process_method;
-use super::parse_util::extract_struct_name;
-use crate::model::{ContractTrait, Method};
+use super::parse_util::validate_attribute_args;
+use super::supertrait_parse::parse_supertrait;
+use crate::model::{ContractTrait, Method, Supertrait};
 
 pub fn parse_contract_trait(
 	args: syn::AttributeArgs,
 	contract_trait: &syn::ItemTrait,
 ) -> ContractTrait {
-	let contract_impl_name = extract_struct_name(args);
+	validate_attribute_args(args);
 
 	let docs = extract_doc(contract_trait.attrs.as_slice());
 
-	let supertrait_paths: Vec<syn::Path> = contract_trait
+	let supertraits: Vec<Supertrait> = contract_trait
 		.supertraits
 		.iter()
-		.map(|supertrait| match supertrait {
-			syn::TypeParamBound::Trait(t) => t.path.clone(),
-			_ => panic!("Contract trait can only extend other traits."),
-		})
+		.map(parse_supertrait)
 		.collect();
 
 	let methods: Vec<Method> = contract_trait
@@ -32,8 +30,8 @@ pub fn parse_contract_trait(
 	ContractTrait {
 		docs,
 		trait_name: contract_trait.ident.clone(),
-		contract_impl_name,
-		supertrait_paths,
+		supertraits,
+		auto_inheritance_modules: Vec::new(),
 		methods,
 	}
 }
